@@ -1,5 +1,5 @@
 /*
- * $Id: auth.c,v 1.20 2005/04/10 20:57:28 calrissian Exp $
+ * $Id: auth.c 269 2005-06-28 12:20:03Z calrissian $
  *
  * Copyright (C) 2002-2004 Fhg Fokus
  * Copyright (C) 2004-2005 Nils Ohlmeier
@@ -87,6 +87,7 @@ void insert_auth(char *message, char *authreq)
 		printf("failed to allocate memory\n");
 		exit_code(255);
 	}
+	memset(backup, 0, strlen(insert)+1);
 	strncpy(backup, insert, strlen(insert)+1);
 
 	begin=STRSTR(authreq, WWWAUTH_STR);
@@ -98,11 +99,12 @@ void insert_auth(char *message, char *authreq)
 		/* make a copy of the auth header to prevent that our searches
 		   hit content of other header fields */
 		end=strchr(begin, '\n');
-		auth=malloc((size_t)((end-begin)+1));
+		auth=malloc((size_t)(end-begin+1));
 		if (!auth) {
 			printf("failed to allocate memory\n");
 			exit_code(255);
 		}
+		memset(auth, 0, (size_t)(end-begin+1));
 		strncpy(auth, begin, (size_t)(end-begin));
 		*(auth+(end-begin))='\0';
 		/* we support Digest and MD5 only */
@@ -123,10 +125,21 @@ void insert_auth(char *message, char *authreq)
 		if ((begin=STRSTR(auth, "algorithm="))!=NULL) {
 			begin+=10;
 			if ((strncmp(begin, "MD5", 3))!=0 && (strncmp(begin, "\"MD5\"", 5))!=0) {
+#ifdef HAVE_STRNCASECMP
+        printf("\nWARNING: algorithm in response is not written RFC compliant!!!\n");
+#else
 				printf("\n%s\nerror: unsupported authentication algorithm\n", 
 					authreq);
 				exit_code(2);
+#endif
 			}
+#ifdef HAVE_STRNCASECMP
+      else if ((strncasecmp(begin, "MD5", 3))!=0 && (strncasecmp(begin, "\"MD5\"", 5))!=0) {
+				printf("\n%s\nerror: unsupported authentication algorithm\n", 
+					authreq);
+				exit_code(2);
+      }
+#endif
 		}
 		/* we need the username at some points */
 		if (auth_username != NULL) {
@@ -138,6 +151,7 @@ void insert_auth(char *message, char *authreq)
 				printf("failed to allocate memory\n");
 				exit_code(255);
 			}
+			memset(usern, 0, strlen(username)+10);
 			if (nameend>0)
 				snprintf(usern, strlen(username)+10, "%s%i", username, namebeg);
 			else
@@ -150,6 +164,7 @@ void insert_auth(char *message, char *authreq)
 			printf("failed to allocate memory\n");
 			exit_code(255);
 		}
+		memset(method, 0, (size_t)(end-message+1));
 		strncpy(method, message, (size_t)(end-message));
 		*(method+(end-message))='\0';
 		/* extract the uri also */
@@ -161,6 +176,7 @@ void insert_auth(char *message, char *authreq)
 			printf("failed to allocate memory\n");
 			exit_code(255);
 		}
+		memset(uri, 0, (size_t)(end-begin+1));
 		strncpy(uri, begin, (size_t)(end-begin));
 		*(uri+(end-begin))='\0';
 
@@ -197,6 +213,7 @@ void insert_auth(char *message, char *authreq)
 				printf("failed to allocate memory\n");
 				exit_code(255);
 			}
+			memset(realm, 0, (size_t)(end-begin+1));
 			strncpy(realm, begin, (size_t)(end-begin));
 			*(realm+(end-begin))='\0';
 		}
@@ -244,6 +261,7 @@ void insert_auth(char *message, char *authreq)
 				printf("failed to allocate memory\n");
 				exit_code(255);
 			}
+			memset(nonce, 0, (size_t)(end-begin+1));
 			strncpy(nonce, begin, (size_t)(end-begin));
 			*(nonce+(end-begin))='\0';
 		}
@@ -256,7 +274,7 @@ void insert_auth(char *message, char *authreq)
 			snprintf(insert, QOP_STR_LEN+QOPAUTH_STR_LEN+3, "%s%s, ", QOP_STR, QOPAUTH_STR);
 			insert+=strlen(insert);
 			nonce_count++;
-			snprintf(insert, NC_STR_LEN+13, "%s%x, ", NC_STR, nonce_count);
+			snprintf(insert, NC_STR_LEN+11, "%s%08x, ", NC_STR, nonce_count);
 			insert+=strlen(insert);
 			cnonce=(unsigned int)rand();
 			/* FIXME: RANDMAX has probably 4 bytes on 32 arch, but 64 bits..? */
@@ -268,7 +286,8 @@ void insert_auth(char *message, char *authreq)
 				printf("failed to allocate memory\n");
 				exit_code(255);
 			}
-			snprintf(qop_tmp, 10+8, "%x:%x:auth:", nonce_count, cnonce);
+			memset(qop_tmp, 0, 100);
+			snprintf(qop_tmp, 8+8+8, "%08x:%x:auth:", nonce_count, cnonce);
 		}
 		/* if no password is given we try it with empty password */
 		if (!password)
@@ -304,7 +323,7 @@ void insert_auth(char *message, char *authreq)
 
 		snprintf(insert, RESPONSE_STR_LEN+1, RESPONSE_STR);
 		insert+=RESPONSE_STR_LEN;
-		snprintf(insert, sizeof(resp_hex)+5,"\"%s\"\r\n", &resp_hex[0]);
+		snprintf(insert, sizeof(resp_hex)+8,"\"%s\"\r\n", &resp_hex[0]);
 		insert+=strlen(insert);
 		/* the auth header is complete, reinsert the rest of the request */
 		strncpy(insert, backup, strlen(backup));
