@@ -1,5 +1,5 @@
 /*
- * $Id: header_f.c,v 1.13 2005/04/10 20:57:28 calrissian Exp $
+ * $Id: header_f.c 268 2005-05-27 08:10:35Z calrissian $
  *
  * Copyright (C) 2002-2004 Fhg Fokus
  * Copyright (C) 2004-2005 Nils Ohlmeier
@@ -234,8 +234,8 @@ void uri_replace(char *mes, char *uri)
 void set_cl(char* mes, int contentlen) {
 	char *cl, *cr, *backup;
 
-	if ((cl=STRSTR(ack, CON_LEN_STR)) == NULL &&
-		(cl=STRSTR(ack, CON_LEN_SHORT_STR)) == NULL) {
+	if ((cl=STRSTR(mes, CON_LEN_STR)) == NULL &&
+		(cl=STRSTR(mes, CON_LEN_SHORT_STR)) == NULL) {
 		printf("missing Content-Lenght in message\n");
 		return;
 	}
@@ -275,7 +275,7 @@ void build_ack(char *invite, char *reply, char *ack) {
 		memcpy(ack, invite, len);
 		*(ack+len+1) = '\0';
 		replace_string(ack, "INVITE", "ACK");
-		cpy_to(ack,reply);
+		cpy_to(reply, ack);
 		set_cl(ack, 0);
 	}
 }
