@@ -1,5 +1,5 @@
 /*
- * $Id: shoot.c,v 1.45 2005/04/11 20:27:59 calrissian Exp $
+ * $Id: shoot.c 270 2005-06-29 18:52:49Z calrissian $
  *
  * Copyright (C) 2002-2004 Fhg Fokus
  * Copyright (C) 2004-2005 Nils Ohlmeier
@@ -657,7 +657,7 @@ void shoot(char *buff)
 						else printf("\n");
 						/* we'll try to handle 301 and 302 here, other 3xx 
 						   are to complex */
-						regcomp(&redexp, "^SIP/[0-9]\\.[0-9] 30[1-2] ", 
+						regcomp(&redexp, "^SIP/[0-9]\\.[0-9] 30[125] ", 
 							REG_EXTENDED|REG_NOSUB|REG_ICASE);
 						if (regexec(&redexp, reply, 0, 0, 0)==0) {
 							/* try to find the contact in the redirect */
@@ -685,6 +685,7 @@ void shoot(char *buff)
 								*foo='\0';
 							if ((crlf=strchr(contact,':'))!=NULL){
 								crlf++;
+								rport = 0;
 								/* extract the needed information*/
 								if ((foo=strchr(crlf,':'))!=NULL){
 									*foo='\0';
@@ -704,13 +705,19 @@ void shoot(char *buff)
 									crlf=foo;
 								}
 								/* get the new destination IP*/
-								address = getaddress(crlf);
-								if (address == 1){
+								if (!rport)
+									address = getsrvaddress(crlf, &rport);
+								if (!address)
+									address = getaddress(crlf);
+								if (!address){
 									printf("error: cannot determine host "
 										"address from Contact of redirect:"
 										"\n%s\n", reply);
 									exit_code(2);
 								}
+								if (!rport) {
+									rport = 5060;
+								}
 							}
 							else{
 								printf("error: missing : in Contact of this "
