@@ -1,5 +1,5 @@
 /*
- * $Id: sipsak.c,v 1.88 2005/04/10 20:57:28 calrissian Exp $
+ * $Id: sipsak.c 270 2005-06-29 18:52:49Z calrissian $
  *
  * Copyright (C) 2002-2004 Fhg Fokus
  * Copyright (C) 2004-2005 Nils Ohlmeier
@@ -270,12 +270,12 @@ int main(int argc, char *argv[])
 	warning_ext=rand_rem=nonce_count=replace_b=invite=message = 0;
 	sleep_ms=empty_contact=nagios_warn=timing = 0;
 	namebeg=nameend=maxforw= -1;
-	numeric=via_ins=redirects=fix_crlf=processes  = 1;
+	numeric=via_ins=redirects=fix_crlf=processes = 1;
 	username=password=replace_str=hostname=contact_uri=mes_body = NULL;
 	con_dis=auth_username = NULL;
 	re = NULL;
 	address = 0;
-	rport = 5060;
+	rport = 0;
 	expires_t = USRLOC_EXP_DEF;
 	memset(buff, 0, BUFSIZE);
 	memset(confirm, 0, BUFSIZE);
@@ -287,9 +287,9 @@ int main(int argc, char *argv[])
 
 	/* lots of command line switches to handle*/
 #ifdef HAVE_GETOPT_LONG
-	while ((c=getopt_long(argc, argv, "a:AB:b:c:C:de:f:Fg:GhH:iIl:Lm:MnNo:O:p:P:q:r:Rs:t:Tu:UvVwW:x:z", l_opts, &option_index)) != EOF){
+	while ((c=getopt_long(argc, argv, "a:Ab:B:c:C:de:f:Fg:GhH:iIl:Lm:MnNo:O:p:P:q:r:Rs:t:Tu:UvVwW:x:z", l_opts, &option_index)) != EOF){
 #else
-	while ((c=getopt(argc,argv,"a:AB:b:c:C:de:f:Fg:GhH:iIl:Lm:MnNo:O:p:P:q:r:Rs:t:Tu:UvVwW:x:z")) != EOF){
+	while ((c=getopt(argc,argv,"a:Ab:B:c:C:de:f:Fg:GhH:iIl:Lm:MnNo:O:p:P:q:r:Rs:t:Tu:UvVwW:x:z")) != EOF){
 #endif
 		switch(c){
 			case 'a':
@@ -313,7 +313,11 @@ int main(int argc, char *argv[])
 				*(mes_body+strlen(optarg)) = '\0';
 				break;
 			case 'C':
+#ifdef HAVE_STRNCASECMP
+				if (!strncasecmp(optarg, "empty", 5) || !strncasecmp(optarg, "none", 4)) {
+#else
 				if (!strncmp(optarg, "empty", 5) || !strncmp(optarg, "none", 4)) {
+#endif
 					empty_contact = 1;
 				}
 				else if (((delim=STRSTR(optarg,"sip:"))!=NULL) ||
@@ -436,7 +440,11 @@ int main(int argc, char *argv[])
 				break;
 			case 'o':
 				sleep_ms = 0;
+#ifdef HAVE_STRNCASECMP
+				if (strncasecmp(optarg, "rand", 4)==0) {
+#else
 				if (strncmp(optarg, "rand", 4)==0) {
+#endif
 					sleep_ms = -2;
 				}
 				else {
@@ -453,9 +461,27 @@ int main(int argc, char *argv[])
 				*(con_dis+strlen(optarg)) = '\0';
 				break;
 			case 'p':
-				address = getaddress(optarg);
+				if ((delim=strchr(optarg,':'))!=NULL){
+					*delim = '\0';
+					delim++;
+					rport = atoi(delim);
+					if (!rport) {
+						printf("error: non-numerical outbound proxy port "
+							"number\n");
+						exit_code(2);
+					}
+				}
+				if (!rport)
+					address = getsrvaddress(optarg, &rport);
+				if (!address)
+					address = getaddress(optarg);
+				if (!address){
+					printf("error:unable to determine the outbound proxy "
+						"address\n");
+					exit_code(2);
+				}
 				break;
-		        case 'P':
+	        case 'P':
 				processes=atoi(optarg);
 				if (!processes) {
 					printf("error: non-numerical number of processes\n");
@@ -491,7 +517,19 @@ int main(int argc, char *argv[])
 				break;
 			case 's':
 				/* we try to extract as much informationas we can from the uri*/
-				if (!strncmp(optarg,"sip",3)){
+#ifdef HAVE_STRNCASECMP
+				if (!strncasecmp(optarg,"sips",4)){
+#else
+				if (!strncmp(optarg,"sips",4)){
+#endif
+					printf("error: sips is not supported yet\n");
+					exit_code(2);
+        }
+#ifdef HAVE_STRNCASECMP
+        else if (!strncasecmp(optarg,"sip",3)){
+#else
+        else if (!strncmp(optarg,"sip",3)){
+#endif
 					if ((delim=strchr(optarg,':'))!=NULL){
 						delim++;
 						if ((delim2=strchr(delim,'@'))!=NULL){
@@ -519,6 +557,8 @@ int main(int argc, char *argv[])
 							strncpy(domainname, delim, strlen(delim));
 							*(domainname+strlen(delim)) = '\0';
 						}
+						if (!rport && !address)
+							address = getsrvaddress(delim, &rport);
 						if (!address)
 							address = getaddress(delim);
 						if (!address){
@@ -571,6 +611,18 @@ int main(int argc, char *argv[])
 #endif
 #ifdef HAVE_GETOPT_LONG
 				printf(", LONG_OPTS");
+#endif
+#ifdef HAVE_OPENSSL_MD5_H
+				printf(", OPENSSL_MD5");
+#endif
+#ifdef HAVE_RULI_H
+				printf(", SRV_SUPPORT");
+#endif
+#ifdef HAVE_STRCASESTR
+        printf(", STR_CASE_INSENSITIVE");
+#endif
+#ifdef HAVE_STRNCASECMP
+        printf(", CMP_CASE_INSENSITIVE");
 #endif
 				printf("\n");
 				exit_code(0);
@@ -599,6 +651,10 @@ int main(int argc, char *argv[])
 		}
 	}
 
+	if (rport == 0) {
+		rport =  5060;
+	}
+
 	/* replace LF with CRLF if we read from a file */
 	if ((file_b) && (fix_crlf)) {
 		insert_cr(buff);
@@ -745,7 +801,7 @@ int main(int argc, char *argv[])
 	
 	/* this is not a cryptographic random number generator,
 	   but hey this is only a test-tool => should be satisfying*/
-	srand(time(0));
+	srand(time(0) ^ getpid());
 	
 	if (processes > 1) {
 		if (signal(SIGCHLD , sigchld_handler)  == SIG_ERR ) {
